@@ -207,7 +207,7 @@ class FastTracker:
             "TrackerVersion": config.tracker_version,
             "ServiceInstance": config.service_instance,
             "Protocol": config.protocol,
-            "LogLevel": config.logging_level,
+            "LoggingLevel": config.logging_level,
             "IgnoreSuffix": config.ignore_suffix,
             "CorrelationElementMaxNumber": config.correlation_element_max_number,
             "CorrelationValueMaxLength": config.correlation_value_max_length,
@@ -222,6 +222,7 @@ class FastTracker:
             "Event": config.event,
             "TenantCodeReader": config.tenant_code_reader,
             "UserCodeReader": config.user_code_reader,
+            "EnvCodeReader": config.env_code_reader,
             "CarrierHeader": config.carrier_header,
         }
 
@@ -232,6 +233,8 @@ class FastTracker:
         :return:
         """
         try:
+            if "custom_event" in config.disable_plugins:
+                raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
             if not operation:
                 raise RuntimeError("operation参数必填")
             context = get_context()
@@ -245,11 +248,15 @@ class FastTracker:
             raise e
 
     def set_component(self, name: str = "CustomEvent"):
+        if "custom_event" in config.disable_plugins:
+            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.component = name
 
     def add_tag(self, key: str = "", val: str = ""):
+        if "custom_event" in config.disable_plugins:
+            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         try:
@@ -258,11 +265,15 @@ class FastTracker:
             raise e
 
     def add_log(self, message: str = ""):
+        if "custom_event" in config.disable_plugins:
+            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.logs.append(Log(items=[LogItem(key="Logging", val=self.log_covert(message))]))
 
     def error_occurred(self, error: Exception):
+        if "custom_event" in config.disable_plugins:
+            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.log(error)
@@ -275,6 +286,8 @@ class FastTracker:
         log模块结束
         :return:
         """
+        if "custom_event" in config.disable_plugins:
+            raise RuntimeError("已在配置Event-Components-CustomEvent中关闭此项")
         if not self.span:
             raise RuntimeError("请先调用begin_span进行实例化")
         self.span.stop()
