@@ -96,7 +96,7 @@ class FastTrackerConfiger:
                 elif key == "FastTracker_SocketPath":
                     setattr(config, "collector_address", val)
                 elif key == "FastTracker_Logging_Level":
-                    setattr(config, "logging_level", val)
+                    setattr(config, "logging_level", val.upper())
                 else:
                     config_name = functions.lower_case_name(key[12:])
                     setattr(config, config_name, val)
